@@ -130,7 +130,7 @@ def 分割线(标题, text, 色选="Nona"):
 
 
 
-def 变量查看(变量名: str, 变量, 色选: str = "红色"):
+def 变量查看(变量名: str, 变量, 色选: str = "红色",自动换行=False):
     """
     FishCosnole LOGS 变量查看模块
 
@@ -169,9 +169,14 @@ def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     计数器 = 计数器 + 22 + 计数器a
     if 计数器>=100:
         计数器=100
+    print(计数器)
+
     print("=" * 计数器)
     print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）"))
-    print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
+    if 变量类型 in ["numpy.ndarray","torch.Tensor"]:
+        print(日志(f"  ||（{颜色('数据', 色选)}：\n{变量}\n）"))
+    else:
+        print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
     print(日志(f"  ||（{颜色('类型', 色选)}: {变量类型}）"))
     print(日志(f"  ||（{颜色('位置', 色选)}:{行位置}）"))
 
